Improve this doc View Source

An object that contains information about the current AngularJS version. This object has the following properties:

- `full` – `{string}` – Full version string, such as "0.9.18".
- `major` – `{number}` – Major version number, such as "0".
- `minor` – `{number}` – Minor version number, such as "9".
- `dot` – `{number}` – Dot version number, such as "18".
- `codeName` – `{string}` – Code name of the release, such as "jiggling-armfat".